###############################################################################
#                                                                             #
# Copyright (C) 2004-2008 Edward d'Auvergne                                   #
#                                                                             #
# This file is part of the program relax.                                     #
#                                                                             #
# relax is free software; you can redistribute it and/or modify               #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation; either version 2 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# relax is distributed in the hope that it will be useful,                    #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with relax; if not, write to the Free Software                        #
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA   #
#                                                                             #
###############################################################################

# Script for calculating NOEs.
##############################


# Create the NOE data pipe.
pipe.create('NOE', 'noe')

# Load the backbone amide 15N spins from a PDB file.
structure.read_pdb('ubi.pdb')
structure.load_spins(spin_id='@N')

# Load the reference spectrum and saturated spectrum peak intensities.
spectrum.read_intensities(file='Ub-noe-off.list', spectrum_id='ref_ave')
spectrum.read_intensities(file='Ub-noe-on.list', spectrum_id='sat_ave')

# Set the spectrum types.
noe.spectrum_type('ref', 'ref_ave')
noe.spectrum_type('sat', 'sat_ave')

# Set the errors.
spectrum.baseplane_rmsd(error=2650, spectrum_id='ref_ave')
spectrum.baseplane_rmsd(error=1440, spectrum_id='sat_ave')

# Individual residue errors.
#spectrum.baseplane_rmsd(error=122000, spectrum_id='ref_ave', spin_id=":114")
#spectrum.baseplane_rmsd(error=8500, spectrum_id='sat_ave', spin_id=":114")

# Peak intensity error analysis.
spectrum.error_analysis()

# Deselect unresolved residues.
#deselect.read(file='unresolved')

# Calculate the NOEs.
calc()

# Save the NOEs.
value.write(param='noe', file='noe.out', force=True)

# Create grace files.
#grace.write(y_data_type='ref_ave', file='ref.agr', force=True)
#grace.write(y_data_type='sat_ave', file='sat.agr', force=True)
#grace.write(y_data_type='noe', file='noe.agr', force=True)

# View the grace files.
#grace.view(file='ref.agr')
#grace.view(file='sat.agr')
#grace.view(file='noe.agr')

# Write the results.
results.write(file='results-noe', dir=None, force=True)

# Save the program state.
state.save('save-noe', force=True)
